pub enum SignatureVerification {
Full,
BackfillOnly,
None,
}Variants
Full
verify all commits, from the firehose and when backfilling a repo from a PDS.
BackfillOnly
only verify commits when backfilling a repo from a PDS.
None
don’t verify anything.